@@ -21,6 +21,7 @@ import Orange.preprocess.transformation
 from Orange.widgets import widget, gui, settings
 from Orange.widgets.utils import itemmodels
 from Orange.widgets.utils.sql import check_sql_input
+from Orange.widgets.widget import Input, Output
 
 
 def get_qualified(module, name):
@@ -137,7 +138,14 @@ class VariableEditor(QWidget):
         self._setup_gui_labels()
 
     def _setup_gui_name(self):
-        self.name_edit = QLineEdit()
+        class OrangeLineEdit(QLineEdit):
+            def keyPressEvent(self, event):
+                if event.key() in [Qt.Key_Return, Qt.Key_Enter]:
+                    self.parent().on_name_changed()
+                else:
+                    super().keyPressEvent(event)
+
+        self.name_edit = OrangeLineEdit()
         self.main_form.addRow("Name:", self.name_edit)
         self.name_edit.editingFinished.connect(self.on_name_changed)
 
@@ -362,8 +370,11 @@ class OWEditDomain(widget.OWWidget):
     icon = "icons/EditDomain.svg"
     priority = 3125
 
-    inputs = [("Data", Orange.data.Table, "set_data")]
-    outputs = [("Data", Orange.data.Table)]
+    class Inputs:
+        data = Input("Data", Orange.data.Table)
+
+    class Outputs:
+        data = Output("Data", Orange.data.Table)
 
     settingsHandler = settings.DomainContextHandler()
 
@@ -410,6 +421,7 @@ class OWEditDomain(widget.OWWidget):
             "A variable name is duplicated.")
 
     @check_sql_input
+    @Inputs.data
     def set_data(self, data):
         """Set input data set."""
         self.closeContext()
@@ -551,11 +563,11 @@ class OWEditDomain(widget.OWWidget):
                 class_vars = all_new_vars[n_attrs: n_attrs + n_class_vars]
                 new_metas = all_new_vars[n_attrs + n_class_vars:]
                 new_domain = Orange.data.Domain(attrs, class_vars, new_metas)
-                new_data = self.data.from_table(new_domain, self.data)
+                new_data = self.data.transform(new_domain)
             else:
                 self.Error.duplicate_var_name()
 
-        self.send("Data", new_data)
+        self.Outputs.data.send(new_data)
 
     def sizeHint(self):
         sh = super().sizeHint()
