@@ -191,13 +191,14 @@ class DiscretizeEditor(BaseEditor):
 class ContinuizeEditor(BaseEditor):
     _Type = type(Continuize.FirstAsBase)
 
-    Continuizers = OrderedDict({
-        Continuize.FrequentAsBase: "Most frequent is base",
-        Continuize.Indicators: "One attribute per value",
-        Continuize.RemoveMultinomial: "Remove multinomial attributes",
-        Continuize.Remove: "Remove all discrete attributes",
-        Continuize.AsOrdinal: "Treat as ordinal",
-        Continuize.AsNormalizedOrdinal: "Divide by number of values"})
+    Continuizers = OrderedDict([
+        (Continuize.FrequentAsBase, "Most frequent is base"),
+        (Continuize.Indicators, "One attribute per value"),
+        (Continuize.RemoveMultinomial, "Remove multinomial attributes"),
+        (Continuize.Remove, "Remove all discrete attributes"),
+        (Continuize.AsOrdinal, "Treat as ordinal"),
+        (Continuize.AsNormalizedOrdinal, "Divide by number of values")
+    ])
 
     def __init__(self, parent=None, **kwargs):
         super().__init__(parent, **kwargs)
@@ -471,7 +472,11 @@ class FeatureSelectEditor(BaseEditor):
         ("Gain ratio", preprocess.score.GainRatio),
         ("Gini index", preprocess.score.Gini),
         ("ReliefF", preprocess.score.ReliefF),
-        ("Fast Correlation Based Filter", preprocess.score.FCBF)
+        ("Fast Correlation Based Filter", preprocess.score.FCBF),
+        ("ANOVA", preprocess.score.ANOVA),
+        ("Chi2", preprocess.score.Chi2),
+        ("RReliefF", preprocess.score.RReliefF),
+        ("Univariate Linear Regression", preprocess.score.UnivariateLinearRegression)
     ]
 
     def __init__(self, parent=None):
@@ -488,7 +493,11 @@ class FeatureSelectEditor(BaseEditor):
              {"text": "Gain Ratio"},
              {"text": "Gini Index"},
              {"text": "ReliefF"},
-             {"text": "Fast Correlation Based Filter"}
+             {"text": "Fast Correlation Based Filter"},
+             {"text": "ANOVA"},
+             {"text": "Chi2"},
+             {"text": "RReliefF"},
+             {"text": "Univariate Linear Regression"}
             ]
         )
         self.layout().addWidget(self.__uni_fs)
