@@ -1,4 +1,5 @@
 import numpy as np
+import scipy.sparse as sp
 
 from AnyQt.QtCore import Qt, QTimer
 from AnyQt.QtGui import (
@@ -21,7 +22,7 @@ from Orange.widgets.settings import \
 from Orange.widgets.utils.itemmodels import DomainModel
 from Orange.widgets.visualize.owscatterplotgraph import OWScatterPlotGraph
 from Orange.widgets.visualize.utils import VizRankDialogAttrPair
-from Orange.widgets.widget import OWWidget, Default, AttributeList, Msg
+from Orange.widgets.widget import OWWidget, AttributeList, Msg, Input, Output
 from Orange.widgets.utils.annotated_data import (create_annotated_table,
                                                  ANNOTATED_DATA_SIGNAL_NAME,
                                                  get_next_name)
@@ -108,13 +109,15 @@ class OWScatterPlot(OWWidget):
     icon = "icons/ScatterPlot.svg"
     priority = 140
 
-    inputs = [("Data", Table, "set_data", Default),
-              ("Data Subset", Table, "set_subset_data"),
-              ("Features", AttributeList, "set_shown_attributes")]
+    class Inputs:
+        data = Input("Data", Table, default=True)
+        data_subset = Input("Data Subset", Table)
+        features = Input("Features", AttributeList)
 
-    outputs = [("Selected Data", Table, Default),
-               (ANNOTATED_DATA_SIGNAL_NAME, Table),
-               ("Features", Table)]
+    class Outputs:
+        selected_data = Output("Selected Data", Table, default=True)
+        annotated_data = Output(ANNOTATED_DATA_SIGNAL_NAME, Table)
+        features = Output("Features", Table, dynamic=False)
 
     settingsHandler = DomainContextHandler()
 
@@ -284,6 +287,7 @@ class OWScatterPlot(OWWidget):
             self.graph.rescale_data()
             self.update_graph()
 
+    @Inputs.data
     def set_data(self, data):
         self.clear_messages()
         self.Information.sampled_sql.clear()
@@ -377,10 +381,11 @@ class OWScatterPlot(OWWidget):
             new_attrs = [a for a in data.domain.attributes + data.domain.metas
                          if a.is_primitive()]
             new_metas = [m for m in data.domain.metas if not m.is_primitive()]
-            data = Table.from_table(Domain(new_attrs, data.domain.class_vars,
-                                           new_metas), data)
+            new_domain = Domain(new_attrs, data.domain.class_vars, new_metas)
+            data = data.transform(new_domain)
         return data
 
+    @Inputs.data_subset
     def set_subset_data(self, subset_data):
         self.warning()
         if isinstance(subset_data, SqlTable):
@@ -394,8 +399,9 @@ class OWScatterPlot(OWWidget):
 
     # called when all signals are received, so the graph is updated only once
     def handleNewSignals(self):
-        self.graph.new_data(self.data_metas_X, self.subset_data)
-        if self.attribute_selection_list and \
+        self.graph.new_data(self.sparse_to_dense(self.data_metas_X),
+                            self.sparse_to_dense(self.subset_data))
+        if self.attribute_selection_list and self.graph.domain and \
                 all(attr in self.graph.domain
                         for attr in self.attribute_selection_list):
             self.attr_x = self.attribute_selection_list[0]
@@ -407,6 +413,37 @@ class OWScatterPlot(OWWidget):
         self.apply_selection()
         self.unconditional_commit()
 
+    def prepare_data(self):
+        """
+        Only when dealing with sparse matrices.
+        GH-2152
+        """
+        self.graph.new_data(self.sparse_to_dense(self.data_metas_X),
+                            self.sparse_to_dense(self.subset_data),
+                            new=False)
+
+    def sparse_to_dense(self, input_data=None):
+        self.vizrank_button.setEnabled(not (self.data and self.data.is_sparse()))
+        if input_data is None or not input_data.is_sparse():
+            return input_data
+        keys = []
+        attrs = {self.attr_x,
+                 self.attr_y,
+                 self.graph.attr_color,
+                 self.graph.attr_shape,
+                 self.graph.attr_size,
+                 self.graph.attr_label}
+        for i, attr in enumerate(input_data.domain):
+            if attr in attrs:
+                keys.append(i)
+        new_domain = input_data.domain.select_columns(keys)
+        dmx = input_data.transform(new_domain)
+        dmx.X = dmx.X.toarray()
+        # TODO: remove once we make sure Y is always dense.
+        if sp.issparse(dmx.Y):
+            dmx.Y = dmx.Y.toarray()
+        return dmx
+
     def apply_selection(self):
         """Apply selection saved in workflow."""
         if self.data is not None and self.selection is not None:
@@ -415,6 +452,7 @@ class OWScatterPlot(OWWidget):
             self.graph.selection[self.selection] = 1
             self.graph.update_colors(keep_colors=True)
 
+    @Inputs.features
     def set_shown_attributes(self, attributes):
         if attributes and len(attributes) >= 2:
             self.attribute_selection_list = attributes[:2]
@@ -441,12 +479,14 @@ class OWScatterPlot(OWWidget):
         self.update_attr()
 
     def update_attr(self):
+        self.prepare_data()
         self.update_graph()
         self.cb_class_density.setEnabled(self.graph.can_draw_density())
         self.cb_reg_line.setEnabled(self.graph.can_draw_regresssion_line())
         self.send_features()
 
     def update_colors(self):
+        self.prepare_data()
         self.cb_class_density.setEnabled(self.graph.can_draw_density())
 
     def update_density(self):
@@ -479,11 +519,9 @@ class OWScatterPlot(OWWidget):
                                   for i in range(np.max(selection))]),
         )
         domain = Domain(data.domain.attributes, data.domain.class_vars, metas)
-        table = Table(
-            domain, data.X, data.Y,
-            metas=np.hstack((data.metas, selection.reshape(len(data), 1))))
-        table.attributes = data.attributes
-        table.ids = data.ids
+        table = data.transform(domain)
+        table.metas[:, len(data.domain.metas):] = \
+            selection.reshape(len(data), 1)
         return table
 
     def send_data(self):
@@ -501,8 +539,8 @@ class OWScatterPlot(OWWidget):
             annotated = self.create_groups_table(self.data, graph.selection)
         else:
             annotated = create_annotated_table(self.data, selection)
-        self.send("Selected Data", selected)
-        self.send(ANNOTATED_DATA_SIGNAL_NAME, annotated)
+        self.Outputs.selected_data.send(selected)
+        self.Outputs.annotated_data.send(annotated)
 
         # Store current selection in a setting that is stored in workflow
         if self.selection is not None and len(selection):
@@ -514,7 +552,7 @@ class OWScatterPlot(OWWidget):
             dom = Domain([], metas=(StringVariable(name="feature"),))
             features = Table(dom, [[self.attr_x], [self.attr_y]])
             features.name = "Features"
-        self.send("Features", features)
+        self.Outputs.features.send(features)
 
     def commit(self):
         self.send_data()
